import requests

from clint.textui import colored, puts, columns
from .config import get_token, get_username, get_password, have_auth_info

import json
import sys


def get_auth_header():
    auth = {"Authorization": "token %s" % get_token()}
    return auth


def delete_gist(gist_id):
    delete_url = 'https://api.github.com/gists/%s' % (gist_id)
    if not have_auth_info:
        puts('{0}. {1}'.format(colored.blue('pygist'),
             colored.green('You need to login to do that ')))
        sys.exit(-1)

    username = get_username()
    password = get_password()
    r = requests.delete(delete_url, auth=(username, password))
    if r.status_code == 204:
        puts('{0}. {1}'.format(colored.blue('pygist'),
            colored.green('gist: %s deleted successfully' % gist_id)))
    else:
        puts('{0}. {1}'.format(colored.blue('pygist'),
             colored.red("You either passed a gist that isn't yours"
                         "or you need to login silly.")))
        sys.exit(-1)


def get_clipboard():
    import subprocess
    data = subprocess.Popen(['pbpaste'], stdout=subprocess.PIPE)
    return data.communicate()[0]


def create_gist(files=None, description=None, paste=False):
    post_url = 'https://api.github.com/gists'
    username = get_username()
    password = get_password()

    post_dict = {'description': description, 'public': True}
    if paste:
        post_dict['files'] = {description: {'content': get_clipboard()}}
    else:
        file_name = lambda x: x.split('/')[-1]
        post_dict['files'] = dict((file_name(file), {'content': open(file).read()}) for file in files)

    r = requests.post(post_url, auth=(username, password), data=json.dumps(post_dict))
    if r.status_code == 201:
        post_resp = json.loads(r.content)
        puts('{0}. {1}'.format(colored.blue('pygist'),
             colored.green('gist: %s created successfully' % post_resp['id'])))
    else:
        puts('{0}. {1}'.format(colored.blue('pygist'),
             colored.green('You need to login to create a gist')))
        sys.exit(-1)



import sys
import os

from clint import args
from clint.textui import colored, puts, indent

from .core import delete_gist, create_gist
from .config import login, make_config, write_config, config_file


def show_help():
    puts('{0}. Created by Olaoluwa Osuntokun'.format(
        colored.blue('pygist')))

    with indent(4):
        puts(colored.green('pygist login'))
        puts(colored.green('pygist create <file1> <file2> <fileN> "description"'))
        puts(colored.green('pygist create paste "description"'))
        puts(colored.green('pygist delete <gist_id>'))
        puts('\n')


def begin():
    if os.path.exists(config_file):
        pass
    else:
        #make config file
        make_config()
        write_config()

    if args.get(0) is None:
        show_help()

    elif args.flags.contains(('--help', '-h')) or args.get(0) == 'help':
        show_help()
        sys.exit(0)

    elif args.flags.contains(('--login', '-l')) or args.get(0) == 'login':
        username = args.get(1)
        if username is None:
            username = raw_input("Github username: ")
            if len(username) == 0:
                puts("{0}. {1}".format(
                    colored.blue("pygist"),
                    colored.red("Username was blank")))

        password = args.get(2)
        if password is None:
            import getpass
            password = getpass.getpass("Password: ")

        login(username, password)

    elif args.get(0) == 'delete':
        if args.get(1) is None:
            puts('{0}. {1}'.format(colored.blue('pygist'),
                 colored.red('You need to pass a gist number to delete')))
        else:
            gist_id = args.get(1)
            delete_gist(gist_id)

    elif args.get(0) == 'create':
        if args.get(1) == 'paste':
            description = args.get(2) or ''
            create_gist(paste=True, description=description)
        elif not args.files:
            puts('{0}. {1}'.format(colored.blue('pygist'),
                 colored.red('You need to pass file as well to create a gist')))
        else:
            description = args.not_files.get(1) or ''
            files = args.files
            create_gist(files=files, description=description)

    else:
        show_help()
        sys.exit(0)



import os
import sys
import ConfigParser
import json
import requests

from clint.textui import colored, puts

config_file = os.path.expanduser('~/.config/pygist/config.ini')

config = ConfigParser.ConfigParser()


def write_config():

    with open(config_file, 'w') as file:
        config.write(file)


def make_config():
    if os.path.exists(config_file):
        pass
    else:
        os.makedirs(os.path.dirname(config_file))
        open(config_file, 'w').close()
        config.add_section('pygist')
        config.set('pygist', 'username', '')
        config.set('pygist', 'password', '')
        config.set('pygist', 'token', '')
        return config


def get_token():
    config.read(config_file)
    return config.get('pygist', 'token')


def get_username():
    config.read(config_file)
    return config.get('pygist', 'username')


def get_password():
    config.read(config_file)
    return config.get('pygist', 'password')


def set_password(password):
    config.set('pygist', 'password', password)
    write_config()


def set_token(token):
    config.set('pygist', 'token', token)
    write_config()


def set_username(username):
    config.set('pygist', 'username', username)
    write_config()


def login(username, password):
    body = json.dumps({'note': "pygist"})
    r = requests.post('https://api.github.com/authorizations', auth=(username, password),
                      data=body)
    if r.status_code == 201:
        puts(colored.green('You have successfully been authenticated with Github'))
    else:
        puts('{0}. {1}'.format(colored.blue('pygist'),
             colored.red('Invalid Credentials')))
        sys.exit(3)

    data = json.loads(r.content)
    token = data["token"]

    if get_username() == username:
        pass
    else:
        set_username(username)

    if get_password() == password:
        pass
    else:
        set_password(password)

    if get_token == token:
        pass
    else:
        set_token(token)


def have_auth_info():
    get_username() != '' and get_token() != ''



import os
import sys

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

sys.path.insert(0, os.path.dirname(os.path.abspath(__file__)))

dependencies = ['clint2', 'requests']

setup(
    name='pygist',
    version='0.211',
    description='a simple cli for interacting with github gists',
    url='https://github.com/Roasbeef/pygist',
    author='Olaoluwa Osuntokun',
    author_email='laolu32@gmail.com',
    install_requires=dependencies,
    packages=['pygist', ],
    license='MIT License',
    long_description=open('README.txt').read(),
    entry_points={
        'console_scripts': [
            'pygist = pygist.cli:begin',
        ],
    },
    classifiers=(
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
    ),
    )
